@@ -2,7 +2,7 @@
  * message.h : SAP Message Class definition
  ****************************************************************************
  * Copyright (C) 1998-2006 VideoLAN
- * $Id: message.h 314 2006-01-31 18:09:32Z courmisch $
+ * $Id: message.h 328 2007-03-11 12:21:00Z courmisch $
  *
  * Authors: Damien Lucas <nitrox@videolan.org>
  *          Rémi Denis-Courmont <rem # videolan dot org>
@@ -24,8 +24,6 @@
 
 #define SAP_ON 1
 #define SAP_OFF 0
-#define SAP_ANNOUNCE 0
-#define SAP_DELETE 1
 #define SAP_IPV4 4
 #define SAP_IPV6 6
 
@@ -36,7 +34,7 @@ class Message {
     uint16_t version;
 
   public:
-    Message(char message_type, uint16_t version, const char* ip);
+    Message(uint16_t version, const char* ip);
     ~Message();
     bool AddProgram(Program*);
     uint8_t* GetFinalMessage(void) { return msg; }
