@@ -2,7 +2,7 @@
  * sapserver.cpp : SAP discovery service mini-server
  ****************************************************************************
  * Copyright (C) 1998-2004 VideoLAN
- * $Id: sapserver.cpp 318 2007-02-20 17:51:13Z courmisch $ 
+ * $Id: sapserver.cpp 328 2007-03-11 12:21:00Z courmisch $ 
  *
  * Authors: Arnaud Schauly <gitan@via.ecp.fr>
  *          Clément Stenac <zorglub@via.ecp.fr>
@@ -222,7 +222,7 @@ int main(int argc, char *argv[])
             }
 
             /* Create a new message */
-            Message *message = new Message(SAP_ANNOUNCE, 0x4212+i, "1.2.3.4");
+            Message *message = new Message(0x4212+i, "1.2.3.4");
             /* Add the program */
             message->AddProgram(config.Programs[i]);
 
@@ -239,18 +239,11 @@ int main(int argc, char *argv[])
             daemon(0,0);
         }
 
+        unsigned n = config.Programs.size() ?: 1;
+        div_t d = div ((1000000000 / n) * config.GetDelay(), 1000000000);
         struct timespec delay;
-        if (config.Programs.size() == 1)
-        {
-            delay.tv_sec = 1;
-            delay.tv_nsec = 0;
-        }
-        else
-        {
-            delay.tv_sec = 0;
-            delay.tv_nsec = 1000000000 * config.GetDelay()
-                                       / config.Programs.size();
-        }
+        delay.tv_sec = d.quot;
+        delay.tv_nsec = d.rem;
 
         signal (SIGINT, exit_handler);
         signal (SIGTERM, exit_handler);
