@@ -2,7 +2,7 @@
  * sapserver.h : SAP discovery service classes definition
  ****************************************************************************
  * Copyright (C) 1998-2004 VideoLAN
- * $Id: sapserver.h 315 2007-02-20 17:34:39Z courmisch $ 
+ * $Id: sapserver.h 328 2007-03-11 12:21:00Z courmisch $ 
  *
  * Authors: Fabrice Ollivier <cif@via.ecp.fr>
  *          Arnaud Schauly <gitan@via.ecp.fr>
@@ -40,7 +40,5 @@
 
 #define SAP_ON 1
 #define SAP_OFF 0
-#define SAP_ANNOUNCE 0
-#define SAP_DELETE 1
 #define SAP_IPV4 4
 #define SAP_IPV6 6
